@@ -12,6 +12,7 @@ from everviz.data.load_csv.get_data import get_data
 from everviz.plugins.summary_plot.util import calculate_statistics
 from everviz.plugins.utils.layout.sidebar_layout import get_sidebar_layout
 from everviz.plugins.summary_plot import summary_callback
+from everviz.util import base64encode
 
 _WELL_RATE_KEYS = ["WOPR", "WWIR", "WGPR", "WGIR"]
 
@@ -105,8 +106,8 @@ class WellsPlot(EvervizPluginABC):
                                 dcc.Graph(
                                     id=self.graph_id,
                                     config={
-                                        "modeBarButtonsToRemove": ["toImage"],
                                         "displaylogo": False,
+                                        "toImageButtonOptions": {"filename": "wells"},
                                     },
                                 )
                             ],
@@ -121,15 +122,12 @@ class WellsPlot(EvervizPluginABC):
         @app.callback(self.plugin_data_output, [self.plugin_data_requested])
         def user_download_data(data_requested):
             if data_requested:
-                return EvervizPluginABC.plugin_data_compress(
-                    [
-                        {
-                            "filename": Path(self.csv_file).name,
-                            "content": get_data(self.csv_file).to_csv(),
-                        }
-                    ]
-                )
-            return ""
+                return {
+                    "filename": Path(self.csv_file).name,
+                    "content": base64encode(get_data(self.csv_file).to_csv()),
+                    "mime_type": "text/csv",
+                }
+            return None
 
         @app.callback(
             Output(self.label_id, "style"),
